<?php

namespace Laraautos\Car\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Laraautos\Car\Interfaces\BrandRepositoryInterface;
use Laraautos\Car\Repositories\Eloquent\Filters\BrandPublicFilter;
use Laraautos\Car\Repositories\Eloquent\Presenters\BrandListPresenter;

class BrandPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        BrandRepositoryInterface $brand
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('laraautos.car.modules'), 'brand', guard_url('brand'));
        $this->repository = $brand;
    }

    /**
     * Show brand's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(BrandPublicFilter::class)
            ->setPresenter(BrandListPresenter::class)
            ->select('brands.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('car::brand.names'))
            ->view('car::public.brand.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show brand.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('car::brand.name'))
            ->view('car::public.brand.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
