<?php

namespace Laraautos\Car\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Laraautos\Car\Interfaces\CarRepositoryInterface;
use Laraautos\Car\Repositories\Eloquent\Filters\CarPublicFilter;
use Laraautos\Car\Repositories\Eloquent\Presenters\CarListPresenter;

class CarPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        CarRepositoryInterface $car
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('laraautos.car.modules'), 'car', guard_url('car'));
        $this->repository = $car;
    }

    /**
     * Show car's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(CarPublicFilter::class)
            ->setPresenter(CarListPresenter::class)
            ->select('cars.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('car::car.names'))
            ->view('car::public.car.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show car.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('car::car.name'))
            ->view('car::public.car.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
