<?php

namespace Laraautos\Car\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Laraautos\Car\Models\Car;

class CarPolicy
{

    /**
     * Determine if the given user can view the car.
     *
     * @param UserPolicyInterface $authUser
     * @param Car $car
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Car $car)
    {
        if ($authUser->canDo('car.car.view') && $authUser->isAdmin()) {
            return true;
        }

        return $car->user_id == user_id() && $car->user_type == user_type();
    }

    /**
     * Determine if the given user can create a car.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('car.car.create');
    }

    /**
     * Determine if the given user can update the given car.
     *
     * @param UserPolicyInterface $authUser
     * @param Car $car
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Car $car)
    {
        if ($authUser->canDo('car.car.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $car->user_id == user_id() && $car->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given car.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Car $car)
    {
        return $car->user_id == user_id() && $car->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given car.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Car $car)
    {
        if ($authUser->canDo('car.car.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given car.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Car $car)
    {
        if ($authUser->canDo('car.car.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
