<?php

namespace Laraautos\Car\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Laraautos\Car\Models\Carmodel;

class CarmodelPolicy
{

    /**
     * Determine if the given user can view the carmodel.
     *
     * @param UserPolicyInterface $authUser
     * @param Carmodel $carmodel
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Carmodel $carmodel)
    {
        if ($authUser->canDo('car.carmodel.view') && $authUser->isAdmin()) {
            return true;
        }

        return $carmodel->user_id == user_id() && $carmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can create a carmodel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('car.carmodel.create');
    }

    /**
     * Determine if the given user can update the given carmodel.
     *
     * @param UserPolicyInterface $authUser
     * @param Carmodel $carmodel
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Carmodel $carmodel)
    {
        if ($authUser->canDo('car.carmodel.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $carmodel->user_id == user_id() && $carmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given carmodel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Carmodel $carmodel)
    {
        return $carmodel->user_id == user_id() && $carmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given carmodel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Carmodel $carmodel)
    {
        if ($authUser->canDo('car.carmodel.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given carmodel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Carmodel $carmodel)
    {
        if ($authUser->canDo('car.carmodel.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
