<?php

namespace Laraautos\Car\Providers;

use Illuminate\Support\ServiceProvider;
use Laraautos\Car\Car;

class CarServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'car');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'car');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Laraautos\Car\Providers\AuthServiceProvider::class);
        $this->app->register(\Laraautos\Car\Providers\RouteServiceProvider::class);
        // $this->app->register(\Laraautos\Car\Providers\EventServiceProvider::class);
        // $this->app->register(\Laraautos\Car\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('laraautos.car', function($app)
        {
            return $this->app->make(Car::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Car to repository
        $this->app->bind(
            'Laraautos\Car\Interfaces\CarRepositoryInterface',
            \Laraautos\Car\Repositories\Eloquent\CarRepository::class
        );        // Bind Carmodel to repository
        $this->app->bind(
            'Laraautos\Car\Interfaces\CarmodelRepositoryInterface',
            \Laraautos\Car\Repositories\Eloquent\CarmodelRepository::class
        );        // Bind Brand to repository
        $this->app->bind(
            'Laraautos\Car\Interfaces\BrandRepositoryInterface',
            \Laraautos\Car\Repositories\Eloquent\BrandRepository::class
        );
    }


    /**
     * Merges user's and car's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'laraautos.car'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Laraautos\Car\Commands\Car::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['laraautos.car'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('laraautos/car.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/car')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/car')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
