<?php

namespace Laraautos\Car\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Laraautos\Car\Models\Car;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Laraautos\Car\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/car/car/*')) {
            Route::bind('car', function ($car) {
                $carRepo = $this->app->make('Laraautos\Car\Interfaces\CarRepositoryInterface');
                return $carRepo->findorNew($car);
            });
        }
        if (Request::is('*/car/carmodel/*')) {
            Route::bind('carmodel', function ($carmodel) {
                $carmodelRepo = $this->app->make('Laraautos\Car\Interfaces\CarmodelRepositoryInterface');
                return $carmodelRepo->findorNew($carmodel);
            });
        }
        if (Request::is('*/car/brand/*')) {
            Route::bind('brand', function ($brand) {
                $brandRepo = $this->app->make('Laraautos\Car\Interfaces\BrandRepositoryInterface');
                return $brandRepo->findorNew($brand);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
